@@ -56,15 +56,13 @@ class LocaleScreen(JadeScreen, Adw.Bin):
         self.window = window
         self.application = application
         self.kwargs = kwargs
-        self.style_provider.load_from_data(".emptyLocales { font-style: italic; font-size: 15px; }", 0)
+        self.style_provider.load_from_data(".emptyLocales { font-style: italic; font-size: 15px; }", -1)
         Gtk.StyleContext.add_provider(
             self.empty_locales.get_style_context(),
             self.style_provider,
             Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
         )
 
-        self.set_valid(True)
-
         builder = Gtk.Builder.new_from_resource(
             "/al/getcryst/jadegui/pages/locale/locale_dialog.ui"
         )
@@ -86,7 +84,7 @@ class LocaleScreen(JadeScreen, Adw.Bin):
         try:
             self.chosen_locales = [self.window.timezone_screen.chosen_timezone.locale]
         except:
-            self.chosen_locales = ["en_US.UTF-8 UTF-8"]
+            self.chosen_locales = ["en_US.UTF-8 UTF-U"]
 
         en_US = LocaleEntry(
             page=self,
@@ -143,10 +141,7 @@ class LocaleScreen(JadeScreen, Adw.Bin):
             self.update_selected_locale_list(add=row.locale, row=locale)
 
     def update_locale_preview(self):
-        try:
-            locale.setlocale(locale.LC_ALL, self.chosen_locales[0][:-6])
-        except:
-            pass
+        locale.setlocale(locale.LC_ALL, self.chosen_locales[0][:-6])
         self.datespreview.set_label(time.strftime(locale.nl_langinfo(locale.D_T_FMT)))
         self.numberpreview.set_label(locale.format_string("%.2f", 1234567.89, grouping=True)+"  -  "+locale.currency(1234.56, grouping=True))
 
@@ -188,7 +183,8 @@ class LocaleScreen(JadeScreen, Adw.Bin):
         self.chosen_locales = [self.window.timezone_screen.chosen_timezone.locale]
         set_list_text(self.main_locale_list, self.chosen_locales[0])
         self.update_locale_preview()
-        self.set_valid(True)
+        if self.chosen_locales != []:
+            self.set_valid(True)
 
     @staticmethod
     def filter_locales(row, terms=None):
